#
# spec file for package iamb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%bcond_without system_openssl
%if %{with system_openssl}
%define features native-tls
%else
%define features bundled
%endif

Name:           iamb
Version:        0.0.9
Release:        2.1
Summary:        A Matrix client for Vim addicts
License:        Apache-2.0
Group:          Productivity/Networking/Instant Messenger
URL:            https://github.com/ulyssa/iamb
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst

%if 0%{?suse_version} > 1500
BuildRequires:  cargo-packaging
BuildRequires:  update-desktop-files
%endif
%if 0%{?debian} || 0%{?ubuntu}
BuildRequires:  rustc >= 1.7.0
BuildRequires:  cargo
%else
BuildRequires:  cargo >= 1.7.0
%endif
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  zstd
%if %{with system_openssl}
%if 0%{?debian} || 0%{?ubuntu}
BuildRequires:  pkg-config
BuildRequires:  libssl-dev
BuildRequires:  libsqlite3-dev
%else
BuildRequires:  pkgconfig(openssl) > 3.0.0
BuildRequires:  pkgconfig(sqlite3)
%endif
%endif

%description
iamb is a Matrix client for the terminal that uses Vim keybindings.

This project is a work-in-progress, and there's still a lot to be
implemented, but much of the basic client functionality is already
present.

%prep
%autosetup -a1
%define build_args --no-default-features --features=%{features}

%build
%if 0%{?suse_version} > 1500
%{cargo_build} %{build_args}
%else
cargo build --release %{build_args}
%endif

%install
%if 0%{?suse_version} > 1500
%{cargo_install} %{build_args}
%else
install -Dm 755 -t "%{buildroot}%{_bindir}" target/release/iamb
%endif

desktop-file-install --dir %{buildroot}%{_datadir}/applications %{name}.desktop
%if 0%{?suse_version} > 1500
%suse_update_desktop_file %{name}
%endif

mkdir -p %{buildroot}%{_mandir}/man{1,5}
install -Dm 644 docs/%{name}.1 -t "%{buildroot}%{_mandir}/man1/"
install -Dm 644 docs/%{name}.5 -t "%{buildroot}%{_mandir}/man5/"
install -Dm 644 docs/%{name}.svg "%{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg"
install -Dm 644 docs/%{name}-256x256.png "%{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png"
install -Dm 644 docs/%{name}-512x512.png "%{buildroot}%{_datadir}/icons/hicolor/512x512/apps/%{name}.png"

%check
%if 0%{?suse_version} > 1500
%{cargo_test} %{build_args}
%else
cargo test %{build_args}
%endif

%files
%doc README.md config.example.toml
%license LICENSE
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_mandir}/man?/%{name}.*

%changelog
* Fri Apr 26 2024 Joshua Smith <smolsheep@opensuse.org>
- Enable building on more distro targets.
* Fri Mar 29 2024 Joshua Smith <smolsheep@opensuse.org>
- Build against system sqlite & openssl. Added openssl and
  sqlite to BuildRequires. Bundled RusTLS is still usable with a
  conditional for where it may be required.
- Install manpages and new icons
- Use upstream tarball
- Update to version 0.0.9:
  Features:
  * Add commands for importing and exporting room keys
  * Add support for desktop notifications
  * Support notifications via terminal bell
  * Support loading a TOML configuration
  * Enable autolinking when rendering Markdown
  * Support configuring user gutter width
  * Support displaying shortcodes instead of Emojis in messages
  Documentation:
  * Add an icon for iamb
  * Update manual pages to use mdoc(7) and list commands
  * Add example of mapping "V" to toggle message selection mode
  Fixes:
  * Ignore key releases on platforms that support it
  * Fix entering thread view when there's no messages yet
  * Wait to log in before starting background tasks
  * Reset message bar when `!` is passed with :cancel
  * Fix image previews in replies
  * Provide better error message for M_UNKNOWN_TOKEN
  Building:
  * Support linking against system OpenSSL
* Sun Mar 17 2024 Joshua Smith <smolsheep@opensuse.org>
- Added desktop file
* Sun Mar 10 2024 Joshua Smith <jsmithfpv@gmail.com>
- Enabled tests
- Update to version 0.0.8.e7f158f:
  * Add support for custom key macros
  * Add support for threads
  * Load receipts for room before acquiring lock
  * Update to ratatui-image@0.8.1
* Tue Mar  5 2024 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.0.8.dd001af:
  * Download rooms keys from backups if they exist
  * Update to matrix-sdk@0.7.1
* Thu Feb 29 2024 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.0.8.84bc6be:
  * Support following the .well-known entries for a username's domain
  * Pull in modalkit repository with a `Cargo.lock`
  * Move LTO into its own "release-lto" profile
  * Update README.md to add openSUSE Tumbleweed (♥)
  * Update modalkit dependencies
  * Indicate and sort on rooms with unread messages
  * Support coloring entire message with the user color
  * Fix truncation/padding for non-ASCII sender names
  * Add a new `:chats` window that lists both DMs and Rooms
* Thu Feb 15 2024 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.0.8.88af9bf:
  * Fix crash on small image preview
  * Fix not showing display names in already synced rooms
  * Update to ratatui-image@0.4.3 to use native sixel lib
  * Fix image preview offset
  * Add support for previewing images in room scrollback
  * feat: desktop file for GUI environment launchers
  * Add support for logging in with SSO
  * Support custom sorting for room and user lists
  * Use mozilla-actions/sccache-action for caching builds
  * Add new command for logging out of iamb session
  * Reduce CPU usage by instead fetching read receipts after
    related sync events
  * Links should be "openable"
  * Update modalkit for newer ratatui and crossterm
  * Enable sending strikethrough text
  * Update Cargo.lock file
  * Support composing messages in an external editor
  * Fix example config
* Mon Oct  2 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.0.8.c7864cb:
  * Enable sending strikethrough text
  * Update Cargo.lock file
  * Support composing messages in an external editor
  * Fix example config
- Partially fixes iamb issue #149 related to username_display
* Sat Jul  8 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 0.0.8:
  Added:
  * Append suffix to download filenames to avoid overwrites
  * Support uploading image attachments from clipboard
  * Support leaving rooms
  * Support hiding server part of username in message scrollback
  * Restore opened tabs and windows upon restart
  * Interpret newlines as line breaks when converting Markdown to
    HTML
  * Indicate when you're editing a message
  * Support configuring which program :open runs
  * Support sending and completing Emoji shortcodes in the message
    bar
  * Indicate number of members in room
  * Show errors fetching space hierarchy when list is empty
  * Indicate when there are new messages below scrollback
    viewport
  * Add manual pages
  Changes:
  * Show Git SHA information when printing version information
  Fixes:
  * Tab completion panics for unrecognized commands
  * Fix error message for undefined download directory
  * Gracefully handle verification events that are unknown locally
  * Use terminal window focus to determine when a message has
    actually been seen
  * ChatStore::set_receipts locks up app for bad connections
  * Need fallback behaviour when dirs::download_dir returns None
  * Code blocks get rendered without line breaks
  * Remove trailing newlines in body
  * Profile session token should only be readable by the user
  * Handle sync failure after successful password entry
* Sun May  7 2023 Joshua Smith <jsmithfpv@gmail.com>
- Initial package for iamb for openSUSE
